summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kautoconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kautoconfig.h')
-rw-r--r--kopete/libkopete/kautoconfig.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/kopete/libkopete/kautoconfig.h b/kopete/libkopete/kautoconfig.h
index 3b10a4d0..c63fcd25 100644
--- a/kopete/libkopete/kautoconfig.h
+++ b/kopete/libkopete/kautoconfig.h
@@ -55,17 +55,17 @@ class TQWidget;
*
* KAutoConfig uses the TQSqlPropertyMap class to determine if it can do
* anything to a widget. Note that KAutoConfig doesn't require a database,
- * it simply uses the functionality that is built into the QSqlPropertyMap
+ * it simply uses the functionality that is built into the TQSqlPropertyMap
* class. New widgets can be added to the map using
* TQSqlPropertyMap::installDefaultMap(). Note that you can't just add any
- * class. The class must have a matching Q_PROPERTY(...) macro defined.
+ * class. The class must have a matching TQ_PROPERTY(...) macro defined.
*
* For example (note that KColorButton is already added and it doesn't need to
* manually added):
*
* kcolorbutton.h defines the following property:
* \code
- * Q_PROPERTY( TQColor color READ color WRITE setColor )
+ * TQ_PROPERTY( TQColor color READ color WRITE setColor )
* \endcode
*
* To add KColorButton the following code would be inserted in the main.
@@ -88,6 +88,7 @@ class TQWidget;
class KOPETE_EXPORT KAutoConfig : public TQObject {
Q_OBJECT
+ TQ_OBJECT
signals:
/**
@@ -120,19 +121,19 @@ public:
* Constructor.
* @param kconfig - KConfig to use when retrieving/saving the widgets
* that KAutoConfig knows about.
* @param parent - Parent object.
* @param name - Object name.
*/
- KAutoConfig( KConfig *kconfig, TQObject *parent=0, const char *name=0 );
+ KAutoConfig( KConfig *kconfig, TQObject *tqparent=0, const char *name=0 );
/**
* Constructor.
* Uses KGlobal::config() when retrieving/saving the widgets that
* KAutoConfig knows about.
* @param parent - Parent object.
* @param name - Object name.
*/
- KAutoConfig( TQObject *parent=0, const char *name=0 );
+ KAutoConfig( TQObject *tqparent=0, const char *name=0 );
/**
* Destructor. Deletes private class.
@@ -141,7 +142,7 @@ public:
/**
* Adds a widget to the list of widgets that should be parsed for any
- * children that KAutoConfig might know when retrieveSettings() is
+ * tqchildren that KAutoConfig might know when retrieveSettings() is
* called. All calls to this function should be made before calling
* retrieveSettings().
* @param widget - Pointer to the widget to add.
@@ -154,7 +155,7 @@ public:
/**
* Ignore the specified child widget when performing an action. Doesn't
- * effect widgets that were added with addWidget() only their children. All
+ * effect widgets that were added with addWidget() only their tqchildren. All
* calls to this function should be made before calling retrieveSettings().
* @param widget - Pointer to the widget that should be ignored.
* Note: Widgets that don't have a name are ignored automatically.
@@ -185,7 +186,7 @@ public:
*
* Example:
* \code
- * addWidgetChangedSignal( "QCheckbox", TQT_SIGNAL(stateChanged(int)) );
+ * addWidgetChangedSignal( "TQCheckbox", TQT_SIGNAL(stateChanged(int)) );
* \endcode
*
* This is generally used in conjunction with the addition of a class
@@ -251,13 +252,13 @@ protected:
TQMap<TQString, TQCString> changedMap;
/**
- * Recursive function that finds all known children.
- * Goes through the children of widget and if any are known and not being
+ * Recursive function that finds all known tqchildren.
+ * Goes through the tqchildren of widget and if any are known and not being
* ignored, stores them in currentGroup. Also checks if the widget
* should be disabled because it is set immutable.
- * @param widget - Parent of the children to look at.
- * @param currentGroup - Place to store known children of widget.
- * @param trackChanges - If true then tracks any changes to the children of
+ * @param widget - Parent of the tqchildren to look at.
+ * @param currentGroup - Place to store known tqchildren of widget.
+ * @param trackChanges - If true then tracks any changes to the tqchildren of
* widget that are known.
* @return bool - If a widget was set to something other then its default.
* @see retrieveSettings()
@@ -120,19 +121,19 @@ public:
* @param kconfig - KConfig to use when retrieving/saving the widgets
* that KAutoConfig knows about.
- * @param parent - Parent object.
+ * @param tqparent - Parent object.
* @param name - Object name.
*/
@@ -120,19 +121,19 @@ public:
* Uses KGlobal::config() when retrieving/saving the widgets that
* KAutoConfig knows about.
- * @param parent - Parent object.
+ * @param tqparent - Parent object.
* @param name - Object name.
*/